--------------------------------------------------------------------------------
Library IEEE;
Use IEEE.Std_Logic_1164.all;
--------------------------------------------------------------------------------

--------------------------------------------------------------------------------
Entity Configurable_U1 Is
  Port(
      CLK : in    std_logic;
      CLK_CAP : in    std_logic;
      EXT_TRIGGER : in    std_logic;
      V_SB : in   std_logic;
      O_SB : in   std_logic;
      R_SB : in   std_logic;
      V_SC : in   std_logic;
      O_SC : in   std_logic;
      R_SC : in   std_logic;
      Set0_Spare : in   std_logic_vector(1 downto 0);
      STATUS : out   std_logic;
      TCK : in   std_logic;
      TDI : in   std_logic;
      TDO : out   std_logic;
      TMS : in   std_logic;
      TRST : in   std_logic
      );
End Configurable_U1;
--------------------------------------------------------------------------------

--------------------------------------------------------------------------------
Architecture structure of Configurable_U1 is

   Component LAX_CFG8
      port
      (
        CH_TRIG  : in  STD_LOGIC_VECTOR(7 downto 0);
        CH_CAP   : in  STD_LOGIC_VECTOR(7 downto 0);
        CLK      : in  STD_LOGIC;
        CLK_CAP  : in  STD_LOGIC;
        STATUS   : out STD_LOGIC;
        DATAO    : out STD_LOGIC_VECTOR(7 downto 0);
        DATAI    : in  STD_LOGIC_VECTOR(7 downto 0);
        ADDR     : out STD_LOGIC_VECTOR(19 downto 0);
        WR       : out STD_LOGIC;
        RD       : out STD_LOGIC;
        SEL_CAP  : out STD_LOGIC_VECTOR(3 downto 0);
        SEL_TRIG : out STD_LOGIC_VECTOR(3 downto 0);
        TCK      : in  STD_LOGIC;
        TDI      : in  STD_LOGIC;
        TDO      : out STD_LOGIC;
        TMS      : in  STD_LOGIC;
        TRIGGER  : in  STD_LOGIC;
        TRST     : in  STD_LOGIC
      );
   End Component;

   Component memory_u1
      port
      (
        CLK      : in  STD_LOGIC;
        WE       : in  STD_LOGIC;
        ADDR     : in  STD_LOGIC_VECTOR(9 downto 0);
        DIN      : in  STD_LOGIC_VECTOR(7 downto 0);
        DOUT     : out STD_LOGIC_VECTOR(7 downto 0)
      );
   End Component;

   Signal Unique_Lax_Signal_Name_Mem_WE   : STD_LOGIC;
   Signal Unique_Lax_Signal_Name_Mem_DIN  : STD_LOGIC_VECTOR(7 downto 0);
   Signal Unique_Lax_Signal_Name_Mem_DOUT : STD_LOGIC_VECTOR(7 downto 0);

   Signal Unique_Lax_Signal_Name_Mem_ADDR : STD_LOGIC_VECTOR(19 Downto 0);
   Signal Unique_Lax_Signal_Name_selcap   : STD_LOGIC_VECTOR(3 downto 0);
   Signal Unique_Lax_Signal_Name_seltrig  : STD_LOGIC_VECTOR(3 downto 0);
   Signal Unique_Lax_Signal_Name_capin    : STD_LOGIC_VECTOR(7 downto 0);
   Signal Unique_Lax_Signal_Name_trigin   : STD_LOGIC_VECTOR(7 downto 0);


Begin
    Unique_Lax_Signal_Name_capin(0) <= V_SB;
    Unique_Lax_Signal_Name_trigin(0) <= V_SB;
    Unique_Lax_Signal_Name_capin(1) <= O_SB;
    Unique_Lax_Signal_Name_trigin(1) <= O_SB;
    Unique_Lax_Signal_Name_capin(2) <= R_SB;
    Unique_Lax_Signal_Name_trigin(2) <= R_SB;
    Unique_Lax_Signal_Name_capin(3) <= V_SC;
    Unique_Lax_Signal_Name_trigin(3) <= V_SC;
    Unique_Lax_Signal_Name_capin(4) <= O_SC;
    Unique_Lax_Signal_Name_trigin(4) <= O_SC;
    Unique_Lax_Signal_Name_capin(5) <= R_SC;
    Unique_Lax_Signal_Name_trigin(5) <= R_SC;
    Unique_Lax_Signal_Name_capin(6) <= Set0_Spare(0);
    Unique_Lax_Signal_Name_trigin(6) <= Set0_Spare(0);
    Unique_Lax_Signal_Name_capin(7) <= Set0_Spare(1);
    Unique_Lax_Signal_Name_trigin(7) <= Set0_Spare(1);

    U1 : LAX_CFG8
      Port Map
      (
        CH_CAP    => Unique_Lax_Signal_Name_capin,
        CH_TRIG   => Unique_Lax_Signal_Name_trigin,
        CLK      => CLK,
        CLK_CAP  => CLK_CAP,
        STATUS   => STATUS,
        DATAO    => Unique_Lax_Signal_Name_Mem_DIN,
        DATAI    => Unique_Lax_Signal_Name_Mem_DOUT,
        WR       => Unique_Lax_Signal_Name_Mem_WE,
        RD       => Open,
        ADDR     => Unique_Lax_Signal_Name_Mem_ADDR,
        SEL_CAP  => Unique_Lax_Signal_Name_selcap,
        SEL_TRIG => Unique_Lax_Signal_Name_seltrig,
        TCK      => TCK,
        TDI      => TDI,
        TDO      => TDO,
        TMS      => TMS,
        TRIGGER  => EXT_TRIGGER,
        TRST     => TRST
      );
    U2 : memory_u1
      Port Map
      (
        CLK      => CLK,
        DIN      => Unique_Lax_Signal_Name_Mem_DIN,
        DOUT     => Unique_Lax_Signal_Name_Mem_DOUT,
        ADDR     => Unique_Lax_Signal_Name_Mem_ADDR(9 Downto 0),
        WE       => Unique_Lax_Signal_Name_Mem_WE
      );

End structure;
--------------------------------------------------------------------------------
